@@ -4,11 +4,11 @@ DASCore - A library for fiber optic sensing.
 # set xarray settings
 from xarray import set_options
 
-from dascore.clients.filespool import FileSpool
+from dascore.clients.dirspool import DirectorySpool
 from dascore.core.patch import Patch
 from dascore.core.spool import MemorySpool, spool
 from dascore.examples import get_example_patch, get_example_spool
-from dascore.io.core import get_format, read, scan, write
+from dascore.io.core import get_format, read, scan, scan_to_df, write
 from dascore.utils.patch import patch_function
 from dascore.version import __last_version__, __version__
 
