@@ -13,7 +13,7 @@ from typing import List, Optional, Union
 import pandas as pd
 
 import dascore
-from dascore.constants import SpoolType, timeable_types
+from dascore.constants import PatchType, SpoolType, timeable_types
 from dascore.core.schema import PatchFileSummary
 from dascore.exceptions import (
     DASCoreError,
@@ -24,6 +24,8 @@ from dascore.exceptions import (
 from dascore.utils.docs import compose_docstring
 from dascore.utils.hdf5 import HDF5ExtError
 from dascore.utils.misc import suppress_warnings
+from dascore.utils.patch import scan_patches
+from dascore.utils.pd import list_ser_to_str
 
 
 class _FiberIOManager:
@@ -76,7 +78,7 @@ class _FiberIOManager:
             priority_formatters.append(formatters[0])
             if len(formatters) > 1:
                 second_class_formatters.extend(formatters[1:])
-        return priority_formatters + second_class_formatters
+        return tuple(priority_formatters + second_class_formatters)
 
     @cache
     def load_plugins(self, format: Optional[str] = None):
@@ -218,8 +220,6 @@ class _FiberIOManager:
 
 # ------------- Protocol for File Format support
 
-# _Manager = _FiberIOManager("dascore.plugin.fiber_io")
-
 
 class FiberIO(ABC):
     """
@@ -281,6 +281,18 @@ class FiberIO(ABC):
         msg = f"FileFormatter: {self.name} has no get_version method"
         raise NotImplementedError(msg)
 
+    @property
+    def implements_scan(self) -> bool:
+        """
+        Returns True if the subclass implements its own scan method else False.
+        """
+        return self.scan.__func__ is not FiberIO.scan
+
+    @property
+    def implements_get_format(self) -> bool:
+        """Return True if the subclass implements its own get_format method."""
+        return self.get_format.__func__ is not FiberIO.get_format
+
     def __hash__(self):
         """FiberIO instances should be uniquely defined by (format, version)"""
         return hash((self.name, self.version))
@@ -337,15 +349,15 @@ def read(
     )
 
 
-@compose_docstring(fields=list(PatchFileSummary.__annotations__))
-def scan(
-    path: Union[Path, str],
+@compose_docstring(fields=list(PatchFileSummary.__fields__))
+def scan_to_df(
+    path: Union[Path, str, PatchType, SpoolType],
     file_format: Optional[str] = None,
     file_version: Optional[str] = None,
     ignore: bool = False,
-) -> List[PatchFileSummary]:
+) -> pd.DataFrame:
     """
-    Scan a file, return the summary dictionary.
+    Scan a path, return a dataframe of contents.
 
     Parameters
     ----------
@@ -357,11 +369,69 @@ def scan(
         If True, ignore non-DAS files by returning an empty list, else raise
         UnknownFiberFormat if unreadable file encountered.
 
+    Returns
+    -------
+    Return a dataframe with columns:
+        {fields}
+    """
+    info = scan(
+        path_or_spool=path,
+        file_format=file_format,
+        file_version=file_version,
+        ignore=ignore,
+    )
+    df = pd.DataFrame([dict(x) for x in info]).assign(
+        dims=lambda x: list_ser_to_str(x["dims"])
+    )
+    return df
+
+
+@compose_docstring(fields=list(PatchFileSummary.__annotations__))
+def scan(
+    path_or_spool: Union[Path, str, PatchType, SpoolType],
+    file_format: Optional[str] = None,
+    file_version: Optional[str] = None,
+    ignore: bool = False,
+) -> List[PatchFileSummary]:
+    """
+    Scan a file, return the summary dictionary.
+
+    Parameters
+    ----------
+    path_or_spool
+        The path the to file to scan
+    file_format
+        Format of the file. If not provided DASCore will try to determine it.
+        Only applicable for path-like inputs.
+    file_version
+        Version of the file. If not provided DASCore will try to determine it.
+        Only applicable for path-like inputs.
+    ignore
+        If True, ignore non-DAS files by returning an empty list, else raise
+        UnknownFiberFormat if unreadable file encountered.
+
     Notes
     -----
     The summary dictionaries contain the following fields:
         {fields}
     """
+    if isinstance(path_or_spool, (str, Path)):
+        return _scan_from_path(
+            path_or_spool,
+            file_format=file_format,
+            file_version=file_version,
+            ignore=ignore,
+        )
+    return scan_patches(path_or_spool)
+
+
+def _scan_from_path(
+    path: Union[Path, str, PatchType, SpoolType],
+    file_format: Optional[str] = None,
+    file_version: Optional[str] = None,
+    ignore: bool = False,
+):
+    """Scan from a single path."""
     if not os.path.exists(path) or os.path.isdir(path):
         msg = f"{path} does not exist or is a directory"
         raise InvalidFiberFile(msg)
