@@ -1,9 +1,9 @@
 """
 Simple script for downloading external files.
 """
+from importlib.resources import files
 from pathlib import Path
 
-import pkg_resources
 import pooch
 
 from dascore.constants import DATA_VERSION
@@ -16,7 +16,7 @@ fetcher = pooch.create(
     version_dev="master",
     env="DFS_DATA_DIR",
 )
-fetcher.load_registry(pkg_resources.resource_stream("dascore", "data_registry.txt"))
+fetcher.load_registry(files("dascore").joinpath("data_registry.txt"))
 
 
 def fetch(name: str, **kwargs) -> Path:
