@@ -5,9 +5,10 @@ import numpy as np
 import pandas as pd
 import pytest
 
-import dascore
-from dascore.core.spool import BaseSpool
-from dascore.utils.time import to_timedelta64
+import dascore as dc
+from dascore.clients.filespool import FileSpool
+from dascore.core.spool import BaseSpool, MemorySpool
+from dascore.utils.time import to_datetime64, to_timedelta64
 
 
 class TestSpoolBasics:
@@ -18,6 +19,12 @@ class TestSpoolBasics:
         out = str(random_spool)
         assert "object at" not in out
 
+    def test_spool_from_emtpy_sequence(self):
+        """Ensure a spool can be created from empty list."""
+        out = dc.spool([])
+        assert isinstance(out, BaseSpool)
+        assert len(out) == 0
+
 
 class TestSlicing:
     """Tests for slicing spools to get sub-spools."""
@@ -44,15 +51,15 @@ class TestSpoolIterablity:
 
     def test_index(self, random_spool):
         """Ensure the stream can be indexed."""
-        assert isinstance(random_spool[0], dascore.Patch)
+        assert isinstance(random_spool[0], dc.Patch)
 
     def test_list_o_patches(self, random_spool):
         """Ensure random_string can be iterated"""
         for pa in random_spool:
-            assert isinstance(pa, dascore.Patch)
+            assert isinstance(pa, dc.Patch)
         patch_list = list(random_spool)
         for pa in patch_list:
-            assert isinstance(pa, dascore.Patch)
+            assert isinstance(pa, dc.Patch)
 
     def test_index_error(self, random_spool):
         """Ensure an IndexError is raised when indexing beyond spool."""
@@ -119,6 +126,33 @@ class TestSelect:
             assert attrs["tag"].startswith("ran")
             assert attrs["time_max"] <= new_max
 
+    def test_multiple_range_selects(self, adjacent_spool_no_overlap):
+        """
+        Ensure multiple range slects can be used in one call (eg time and distance).
+        """
+        spool = adjacent_spool_no_overlap
+        contents = spool.get_contents()
+        # get new time/distance ranges and select them
+        time_min = to_datetime64(contents["time_min"].min() + to_timedelta64(4))
+        time_max = to_datetime64(contents["time_max"].max() - to_timedelta64(4))
+        distance_min = contents["distance_min"].min() + 50
+        distance_max = contents["distance_min"].max() - 50
+        new_spool = spool.select(
+            time=(time_min, time_max), distance=(distance_min, distance_max)
+        )
+        # First check content df honors new ranges
+        new_contents = new_spool.get_contents()
+        assert (new_contents["time_min"] >= time_min).all()
+        assert (new_contents["time_max"] <= time_max).all()
+        assert (new_contents["distance_min"] >= distance_min).all()
+        assert (new_contents["distance_max"] <= distance_max).all()
+        # then check patches
+        for patch in new_spool:
+            assert patch.attrs["time_min"] >= time_min
+            assert patch.attrs["time_max"] <= time_max
+            assert patch.attrs["distance_min"] >= distance_min
+            assert patch.attrs["distance_max"] <= distance_max
+
 
 class TestChunk:
     """
@@ -155,7 +189,7 @@ class TestChunk:
         # get contents of chunked spool
         chunk_df = new.get_contents()
         new_patches = list(new)
-        new_patch = dascore.MemorySpool(new_patches)
+        new_patch = dc.MemorySpool(new_patches)
         # get content of spool created from patches in chunked spool.
         new_content = new_patch.get_contents()
         # these should be (nearly) identical.
@@ -163,12 +197,18 @@ class TestChunk:
         cols = sorted(common - {"history"})  # no need to compare history
         assert chunk_df[cols].equals(new_content[cols])
 
+    def test_merge_empty_spool(self, tmp_path_factory):
+        """Ensure merge doesn't raise on empty spools"""
+        spool = dc.spool([])
+        merged = spool.chunk(time=None)
+        assert len(merged) == 0
+
 
 class TestMergePatchesWithChunk:
     """Tests for merging patches together using chunk method."""
 
     @pytest.fixture()
-    def desperate_spool_no_overlap(self, random_patch) -> dascore.MemorySpool:
+    def desperate_spool_no_overlap(self, random_patch) -> dc.MemorySpool:
         """
         Create streams that do not overlap at all.
         Ensure the patches are not sorted in temporal order.
@@ -179,17 +219,17 @@ class TestMergePatchesWithChunk:
         pa2 = random_patch.update_attrs(time_min=t2 + d_time)
         t3 = pa2.attrs["time_max"]
         pa3 = pa2.update_attrs(time_min=t3 + d_time)
-        return dascore.MemorySpool([pa2, pa1, pa3])
+        return dc.MemorySpool([pa2, pa1, pa3])
 
     @pytest.fixture()
-    def spool_complete_overlap(self, random_patch) -> dascore.MemorySpool:
+    def spool_complete_overlap(self, random_patch) -> dc.MemorySpool:
         """
         Create a stream which overlaps each other completely.
         """
-        return dascore.MemorySpool([random_patch, random_patch])
+        return dc.MemorySpool([random_patch, random_patch])
 
     @pytest.fixture()
-    def spool_slight_gap(self, random_patch) -> dascore.MemorySpool:
+    def spool_slight_gap(self, random_patch) -> dc.MemorySpool:
         """
         Create a stream which has a 1.1 * dt gap.
         """
@@ -199,7 +239,7 @@ class TestMergePatchesWithChunk:
         pa2 = random_patch.update_attrs(time_min=t2 + dt * 1.1)
         t3 = pa2.attrs["time_max"]
         pa3 = pa2.update_attrs(time_min=t3 + dt * 1.1)
-        return dascore.MemorySpool([pa2, pa1, pa3])
+        return dc.MemorySpool([pa2, pa1, pa3])
 
     def test_merge_adjacent(self, adjacent_spool_no_overlap):
         """Test simple merge of patches."""
@@ -237,39 +277,72 @@ class TestMergePatchesWithChunk:
         out = spool_slight_gap.chunk(time=None)
         assert len(out) == 1
 
+    def test_merge_transposed_patches(self, spool_complete_overlap):
+        """Ensure if one of the patches is transposed merge still works"""
+        spoo = spool_complete_overlap
+        # transpose patch and remove transpose from history so patch will
+        # merge with other patch
+        new_patch = spoo[0].transpose().update_attrs(history=spoo[1].attrs["history"])
+        new = dc.spool(
+            [new_patch, spoo[1]],
+        )
+        new_merged = new.chunk(time=None)
+        old_merged = spool_complete_overlap.chunk(time=None)
+        assert len(new_merged) == len(old_merged) == 1
+        assert new_merged[0].equals(old_merged[0])
+
 
 class TestGetSpool:
     """Test getting spool from various sources."""
 
     def test_spool_from_spool(self, random_spool):
         """Ensure a spool is valid input to get spool."""
-        out = dascore.spool(random_spool)
+        out = dc.spool(random_spool)
         for p1, p2 in zip(out, random_spool):
             assert p1.equals(p2)
 
     def test_spool_from_patch_sequence(self, random_spool):
         """Ensure a list of patches returns a spool"""
-        spool_list = dascore.spool(list(random_spool))
-        spool_tuple = dascore.spool(tuple(random_spool))
+        spool_list = dc.spool(list(random_spool))
+        spool_tuple = dc.spool(tuple(random_spool))
         for p1, p2, p3 in zip(spool_tuple, spool_list, random_spool):
             assert p1.equals(p2)
             assert p2.equals(p3)
 
     def test_spool_from_single_file(self, terra15_das_example_path):
         """Ensure a single file path returns a spool."""
-        out1 = dascore.spool(terra15_das_example_path)
+        out1 = dc.spool(terra15_das_example_path)
         assert isinstance(out1, BaseSpool)
         # ensure format works.
-        out2 = dascore.spool(terra15_das_example_path, file_format="terra15")
+        out2 = dc.spool(terra15_das_example_path, file_format="terra15")
         assert isinstance(out2, BaseSpool)
         assert len(out1) == len(out2)
 
     def test_non_existent_file_raises(self):
         """A path that doesn't exist should raise."""
         with pytest.raises(Exception, match="get spool from"):
-            dascore.spool("here_or_there?")
+            dc.spool("here_or_there?")
 
     def test_non_supported_type_raises(self):
         """A type that can't contain patches should raise."""
         with pytest.raises(Exception, match="not get spool from"):
-            dascore.spool(1.2)
+            dc.spool(1.2)
+
+    def test_file_spool(self, random_spool, tmp_path_factory):
+        """
+        Tests for getting a file spool vs in-memory spool. Basically,
+        if a format supports scanning a FileSpool is returned. If it doesn't,
+        all the file contents have to be loaded into memory to scan so a
+        MemorySpool is just returned.
+        """
+        path = tmp_path_factory.mktemp("file_spoolin")
+        dasdae_path = path / "patch.h5"
+        pickle_path = path / "patch.pkl"
+        dc.write(random_spool, dasdae_path, "dasdae")
+        dc.write(random_spool, pickle_path, "pickle")
+
+        dasdae_spool = dc.spool(dasdae_path)
+        assert isinstance(dasdae_spool, FileSpool)
+
+        pickle_spool = dc.spool(pickle_path)
+        assert isinstance(pickle_spool, MemorySpool)
